import setuptools

setuptools.setup(
    name="stitchpy",
    version="0.0.4",
    author="Xiaozhe Yao",
    author_email="xiaozhe.yaoi@gmail.com",
    description="Python Binding for Pano Tools",
    url="https://autoai.org",
    packages=setuptools.find_packages(),
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering",
        "Topic :: Software Development",
    ],
    project_urls={
        "Bug Tracker": "https://github.com/xzyaoi/pystitch/issues",
        "Documentation": "https://cvpm.autoai.org",
        "Source Code": "https://github.com/xzyaoi/pystitch",
    },
)